@@ -3,7 +3,7 @@ from security import secret_manager
 import json
 from pymemcache.client import base
 import base64
-from flask import jsonify
+from flask import jsonify, make_response
 
 
 class ValidateHeader:
@@ -31,11 +31,13 @@ class ValidateHeader:
         if ip:
             print("Incoming request from IP: {}".format(ip))
             if ip not in ip_list:
-                abort(403, {'message': 'Forbidden Access: {} Not an authorized IP'.format(ip)})
+                abort(make_response(jsonify({'message': 'Forbidden Access: {} Not an authorized IP'.format(ip),
+                                             'status_code': 403})))
         else:
-            return jsonify({'Exception': "AuthFailure",
-                            'message': 'No IP found in RequestHeader,Please check Nginx config or header of the request',
-                            'status_code': '424'})
+            return abort(make_response(jsonify({'Exception': "AuthFailure",
+                                                'message': 'No IP found in RequestHeader,Please check Nginx config '
+                                                           'or header of the request',
+                                                'status_code': '424'})))
 
     @staticmethod
     def check_okta_token(**kwargs):
@@ -60,11 +62,12 @@ class ValidateHeader:
             client = base.Client((aws_elastic_cache_hostname, int(port)))
 
             if not client.get(memcache_key):
-                abort(403, {'message': 'Forbidden Access: Request not from an authorized user'})
+                abort(make_response(jsonify({'message': 'Forbidden Access: Request not from an authorized user',
+                                             'status_code': 403})))
         else:
-            return jsonify({'Exception': "AuthFailure",
-                            'message': 'No Authorization header provided.',
-                            'status_code': '424'})
+            return abort(make_response(jsonify({'Exception': "AuthFailure",
+                                                'message': 'No Authorization header provided.',
+                                                'status_code': '424'})))
 
     @staticmethod
     def base64_encode(token):
